You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@airflow.apache.org by ur...@apache.org on 2023/10/03 06:04:51 UTC

[airflow] branch main updated: Fix typo in DataplexGetDataQualityScanResultOperator (#34681)

This is an automated email from the ASF dual-hosted git repository.

uranusjr pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/airflow.git


The following commit(s) were added to refs/heads/main by this push:
     new 7c440ca184 Fix typo in DataplexGetDataQualityScanResultOperator (#34681)
7c440ca184 is described below

commit 7c440ca18497c4134a9dd9237c2029afa58f85dd
Author: pokoyakazan <ok...@gmail.com>
AuthorDate: Tue Oct 3 15:04:43 2023 +0900

    Fix typo in DataplexGetDataQualityScanResultOperator (#34681)
---
 airflow/providers/google/cloud/operators/dataplex.py | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/airflow/providers/google/cloud/operators/dataplex.py b/airflow/providers/google/cloud/operators/dataplex.py
index b4392b56f0..3a85961d2d 100644
--- a/airflow/providers/google/cloud/operators/dataplex.py
+++ b/airflow/providers/google/cloud/operators/dataplex.py
@@ -1053,10 +1053,10 @@ class DataplexGetDataQualityScanResultOperator(GoogleCloudBaseOperator):
     :param fail_on_dq_failure: If set to true and not all Data Quality scan rules have been passed,
         an exception is thrown. If set to false and not all Data Quality scan rules have been passed,
         execution will finish with success.
     :param wait_for_result: Flag indicating whether to wait for the result of a job execution
         or to return the job in its current state.
     :param result_timeout: Value in seconds for which operator will wait for the Data Quality scan result
-        when the flag `wait_for_result = True`.
+        when the flag `wait_for_results = True`.
         Throws exception if there is no result found after specified amount of seconds.
     :param polling_interval_seconds: time in seconds between polling for job completion.
         The value is considered only when running in deferrable mode. Must be greater than 0.
@@ -1053,10 +1053,10 @@ class DataplexGetDataQualityScanResultOperator(GoogleCloudBaseOperator):
         an exception is thrown. If set to false and not all Data Quality scan rules have been passed,
         execution will finish with success.
-    :param wait_for_result: Flag indicating whether to wait for the result of a job execution
+    :param wait_for_results: Flag indicating whether to wait for the result of a job execution
         or to return the job in its current state.
     :param result_timeout: Value in seconds for which operator will wait for the Data Quality scan result